Development Guide — Fedimg 1.3.0 documentation

# Development Guide

Fedimg is application written in Python. It uses libcloud to connect with the external Cloud providers.

1. Clone the repository from Github:

       $ git clone git@github.com:fedora-infra/fedimg.git

2. Installing the dependencies:

       $ virtualenv fedimg_env
       $ source ./fedimg_env/bin/activate
       $ python setup.py develop

3. Setting up the configuration:

       $ mkdir -p /etc/fedimg/
       $ cp fedimg-conf.toml.example /etc/fedimg/fedimg-conf.toml

4. Setup AWS credentials

   > Update the values of `access_id` and `secret_key` with your AWS tokens in `/etc/fedimg/fedimg-conf.toml` file.

5. Setup the euca2ools configuration:

       $ mkdir ~/.euca
       $ cp euca-fedimg.ini ~/.euca/config.ini

6. Setup the euc2ools credentials

   > Update the values of `key-id` and `secret-key` with your AWS tokens in the `~/.euca/config.ini` file.

7. Run the fedmsg-hub:

       $ fedmsg-hub

Happy Hacking!